@@ -16,7 +16,7 @@ Spec:
 """
 
 from pyiron_base.generic.datacontainer import DataContainer
-from pyiron_base.generic.hdfio import FileHDFio
+from pyiron_base.generic.hdfio import ProjectHDFio
 
 __author__ = "Liam Huber"
 __copyright__ = (
@@ -45,18 +45,14 @@ class ProjectData(DataContainer):
         """
         super().__init__(*args, **kwargs)
         self._project = project
-        try:
-            self.read()
-        except KeyError:
-            pass
 
     def read(self):
         """Read existing data from project-level storage."""
-        hdf = FileHDFio(file_name=self._project.path + "project_data")
+        hdf = ProjectHDFio(self._project, file_name="project_data")
         if self.table_name not in hdf.list_groups():
             raise KeyError(f"Table name {self.table_name} was not found -- Project data is empty.")
         self.from_hdf(hdf=hdf)
 
     def write(self):
         """Write data to project-level storage."""
-        self.to_hdf(FileHDFio(file_name=self._project.path + "project_data"))
+        self.to_hdf(ProjectHDFio(self._project, file_name="project_data"))
