@@ -3,13 +3,14 @@
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 """
 The settings file provides the attributes of the configuration as properties.
+
+The settings object is additionally responsible for the queue adapter, the logger, and the publications list.
 """
 
 import os
 import importlib
 from configparser import ConfigParser
 from pyiron_base.settings.logger import setup_logger
-from pyiron_base.database.generic import DatabaseAccess
 
 __author__ = "Jan Janssen"
 __copyright__ = (
@@ -75,45 +76,14 @@ class Settings(metaclass=Singleton):
             "project_check_enabled": True,
             "disable_database": False,
         }
-        environment = os.environ
-        if "PYIRONCONFIG" in environment.keys():
-            config_file = environment["PYIRONCONFIG"]
-        else:
-            config_file = os.path.expanduser(os.path.join("~", ".pyiron"))
-        if os.path.isfile(config_file):
-            self._config_parse_file(config_file)
-        elif any(["PYIRON" in e for e in environment.keys()]):
-            self._configuration = self.get_config_from_environment(
-                environment=environment,
-                config=self._configuration
-            )
-        else:
-            self._configuration["sql_file"] = "~/pyiron.db"
-            self._configuration["project_check_enabled"] = False
+        self._update_configuration(config)
 
-        # Take dictionary as primary source - overwrite everything
-        self._read_external_config(config=config)
-        if "CONDA_PREFIX" in environment.keys() and os.path.exists(os.path.join(environment["CONDA_PREFIX"], "share", "pyiron")):
-            self._configuration["resource_paths"].append(os.path.join(environment["CONDA_PREFIX"], "share", "pyiron"))
-        elif "CONDA_DIR" in environment.keys() and os.path.exists(os.path.join(environment["CONDA_DIR"], "share", "pyiron")):
-            self._configuration["resource_paths"].append(os.path.join(environment["CONDA_DIR"], "share", "pyiron"))
-
-        self._configuration["project_paths"] = [
-            convert_path(path) + "/" if path[-1] != "/" else convert_path(path)
-            for path in self._configuration["project_paths"]
-        ]
-        self._configuration["resource_paths"] = [
-            convert_path(path) for path in self._configuration["resource_paths"]
-        ]
-
-        # Build the SQLalchemy connection strings
-        self._database_is_disabled = self._configuration["disable_database"]
-        if not self.database_is_disabled:
+        # Build the SQLalchemy connection strings from config data
+        if not self._configuration["disable_database"]:
             self._configuration = self.convert_database_config(
                 config=self._configuration
             )
-        self._database = None
-        self._use_local_database = False
+
         self._queue_adapter = None
         self._queue_adapter = self._init_queue_adapter(
             resource_path_lst=self._configuration["resource_paths"]
@@ -123,28 +93,48 @@ class Settings(metaclass=Singleton):
         self.publication_add(self.publication)
 
     @property
-    def using_local_database(self):
-        return self._use_local_database
+    def configuration(self):
+        return self._configuration
 
-    @property
-    def database(self):
-        return self._database
+    def _update_configuration(self, config):
+        environment = os.environ
+        if "PYIRONCONFIG" in environment.keys():
+            config_file = environment["PYIRONCONFIG"]
+        else:
+            config_file = os.path.expanduser(os.path.join("~", ".pyiron"))
+
+        if os.path.isfile(config_file):
+            self._config_parse_file(config_file)
+        elif any(["PYIRON" in e for e in environment.keys()]):
+            self._configuration = self._get_config_from_environment(
+                environment=environment,
+                config=self._configuration
+            )
+        else:
+            self._configuration["sql_file"] = "~/pyiron.db"
+            self._configuration["project_check_enabled"] = False
+
+        # Take dictionary as primary source - overwrite everything
+        self._read_external_config(config=config)
+        if "CONDA_PREFIX" in environment.keys() \
+                and os.path.exists(os.path.join(environment["CONDA_PREFIX"], "share", "pyiron")):
+            self._configuration["resource_paths"].append(os.path.join(environment["CONDA_PREFIX"], "share", "pyiron"))
+        elif "CONDA_DIR" in environment.keys() \
+                and os.path.exists(os.path.join(environment["CONDA_DIR"], "share", "pyiron")):
+            self._configuration["resource_paths"].append(os.path.join(environment["CONDA_DIR"], "share", "pyiron"))
+
+        self._configuration["project_paths"] = [
+            convert_path(path) if path.endswith("/") else convert_path(path) + "/"
+            for path in self._configuration["project_paths"]
+        ]
+        self._configuration["resource_paths"] = [
+            convert_path(path) for path in self._configuration["resource_paths"]
+        ]
 
     @property
     def queue_adapter(self):
         return self._queue_adapter
 
-    @property
-    def project_check_enabled(self):
-        if self.database_is_disabled:
-            return False
-        else:
-            return self._configuration["project_check_enabled"]
-
-    @property
-    def database_is_disabled(self):
-        return self._database_is_disabled
-
     @property
     def publication_lst(self):
         """
@@ -192,139 +182,6 @@ class Settings(metaclass=Singleton):
         """
         return self._configuration["resource_paths"]
 
-    @property
-    def connection_timeout(self):
-        """
-        Get the connection timeout in seconds.  Zero means close the database after every connection.
-
-        Returns:
-            int: timeout in seconds
-        """
-        return self._configuration["connection_timeout"]
-
-    @connection_timeout.setter
-    def connection_timeout(self, val):
-        self._configuration["connection_timeout"] = val
-
-    def open_connection(self):
-        """
-        Internal function to open the connection to the database. Only after this function is called the database is
-        accessable.
-        """
-        if self._database is None and not self.database_is_disabled:
-            self._database = DatabaseAccess(
-                self._configuration["sql_connection_string"],
-                self._configuration["sql_table_name"],
-                timeout=self._configuration["connection_timeout"]
-            )
-
-    def switch_to_local_database(self, file_name="pyiron.db", cwd=None):
-        """
-        Swtich to an local SQLite based database.
-
-        Args:
-            file_name (str): SQLite database file name
-            cwd (str/None): directory where the SQLite database file is located in
-        """
-        if not self._use_local_database:
-            if cwd is None and not os.path.isabs(file_name):
-                file_name = os.path.join(os.path.abspath(os.path.curdir), file_name)
-            elif cwd is not None:
-                file_name = os.path.join(cwd, file_name)
-            self.close_connection()
-            self.open_local_sqlite_connection(connection_string="sqlite:///" + file_name)
-        else:
-            print("Database is already in local mode or disabled!")
-
-    def open_local_sqlite_connection(self, connection_string):
-        self._database = DatabaseAccess(connection_string, self._configuration["sql_table_name"])
-        self._use_local_database = True
-        if self.database_is_disabled:
-            self._database_is_disabled = False
-
-    def switch_to_central_database(self):
-        """
-        Switch to central database
-        """
-        if self._use_local_database:
-            self.close_connection()
-            self._database_is_disabled = self._configuration["disable_database"]
-            if not self.database_is_disabled:
-                self._database = DatabaseAccess(
-                    self._configuration["sql_connection_string"],
-                    self._configuration["sql_table_name"],
-                )
-            else:
-                self._database = None
-            self._use_local_database = False
-        else:
-            print("Database is already in central mode or disabled!")
-
-    def switch_to_viewer_mode(self):
-        """
-        Switch from user mode to viewer mode - if viewer_mode is enable pyiron has read only access to the database.
-        """
-        if self._configuration["sql_view_connection_string"] is not None and not self.database_is_disabled:
-            if not self._database.viewer_mode:
-                self.close_connection()
-                self._database = DatabaseAccess(
-                    self._configuration["sql_view_connection_string"],
-                    self._configuration["sql_view_table_name"],
-                )
-                self._database.viewer_mode = True
-            else:
-                print("Database is already in viewer mode!")
-        else:
-            print("Viewer Mode is not available on this pyiron installation.")
-
-    def switch_to_user_mode(self):
-        """
-        Switch from viewer mode to user mode - if viewer_mode is enable pyiron has read only access to the database.
-        """
-        if self._configuration["sql_view_connection_string"] is not None and not self.database_is_disabled:
-            if self._database.viewer_mode:
-                self.close_connection()
-                self._database = DatabaseAccess(
-                    self._configuration["sql_connection_string"],
-                    self._configuration["sql_table_name"],
-                )
-                self._database.viewer_mode = True
-            else:
-                print("Database is already in user mode!")
-        else:
-            print("Viewer Mode is not available on this pyiron installation.")
-
-    def close_connection(self):
-        """
-        Internal function to close the connection to the database.
-        """
-        if hasattr(self, "_database") and self._database is not None:
-            self._database.conn.close()
-            self._database = None
-
-    def top_path(self, full_path):
-        """
-        Validated that the full_path is a sub directory of one of the pyrion environments loaded.
-
-        Args:
-            full_path (str): path
-
-        Returns:
-            str: path
-        """
-        if full_path[-1] != "/":
-            full_path += "/"
-        if not self.project_check_enabled:
-            return None
-        for path in self._configuration["project_paths"]:
-            if path in full_path:
-                return path
-        raise ValueError(
-            "the current path {0} is not included in the .pyiron configuration. {1}".format(
-                full_path, self._configuration["project_paths"]
-            )
-        )
-
     # private functions
     @staticmethod
     def _init_queue_adapter(resource_path_lst):
@@ -392,17 +249,19 @@ class Settings(metaclass=Singleton):
             ]
         else:
             ValueError("No project path identified!")
+
         if parser.has_option(section, "PROJECT_CHECK_ENABLED"):
-            self._configuration["project_check_enabled"] = \
-                parser.getboolean(section, "PROJECT_CHECK_ENABLED")
+            self._configuration["project_check_enabled"] = parser.getboolean(section, "PROJECT_CHECK_ENABLED")
+
         if parser.has_option(section, "DISABLE_DATABASE"):
-            self._configuration["disable_database"] = \
-                parser.getboolean(section, "DISABLE_DATABASE")
+            self._configuration["disable_database"] = parser.getboolean(section, "DISABLE_DATABASE")
+
         if parser.has_option(section, "RESOURCE_PATHS"):
             self._configuration["resource_paths"] = [
                 convert_path(c.strip())
                 for c in parser.get(section, "RESOURCE_PATHS").replace(",", ":").replace(";", ":").split(":")
             ]
+
         if self._configuration["sql_type"] in ["Postgres", "MySQL"]:
             if (
                 parser.has_option(section, "USER")
@@ -420,6 +279,7 @@ class Settings(metaclass=Singleton):
                     "If type Postgres or MySQL are selected the options USER, PASSWD, HOST and NAME are"
                     "required in the configuration file."
                 )
+
             if (
                 parser.has_option(section, "VIEWERUSER")
                 & parser.has_option(section, "VIEWERPASSWD")
@@ -447,6 +307,7 @@ class Settings(metaclass=Singleton):
                 self._configuration["sql_file"] = parser.get(
                     section, "DATABASE_FILE"
                 ).replace("\\", "/")
+
         if parser.has_option(section, "JOB_TABLE"):
             self._configuration["sql_table_name"] = parser.get(section, "JOB_TABLE")
 
@@ -524,7 +385,7 @@ class Settings(metaclass=Singleton):
                     )
 
     @staticmethod
-    def get_config_from_environment(environment, config):
+    def _get_config_from_environment(environment, config):
         env_key_mapping = {
             "PYIRONUSER": "user",
             "PYIRONRESOURCEPATHS": "resource_paths",
